@@ -1,7 +1,10 @@
-from barril.curve.curve import Curve
-from barril.units import Array, ObtainQuantity, UnitDatabase
 import pytest
 
+from barril.curve.curve import Curve
+from barril.units import Array
+from barril.units import ObtainQuantity
+from barril.units import UnitDatabase
+
 
 @pytest.fixture
 def unit_database():
@@ -29,7 +32,7 @@ def unit_database():
     UnitDatabase.PopSingleton()
 
 
-def testCurves(unit_database):
+def testCurves(unit_database) -> None:
     import numpy
 
     r = ObtainQuantity("m", "length")
@@ -41,17 +44,17 @@ def testCurves(unit_database):
     domain10 = Array("time", values=numpy.array(list(range(10)), dtype=numpy.int32), unit="s")
 
     with pytest.raises(ValueError):
-        Curve(values10, domain9)
+        Curve(values10, domain9)  # type:ignore[arg-type]
 
-    c = Curve(values10, domain10)
+    c = Curve(values10, domain10)  # type:ignore[arg-type]
 
     with pytest.raises(ValueError):
-        c.SetDomain(domain9)
+        c.SetDomain(domain9)  # type:ignore[arg-type]
     with pytest.raises(ValueError):
-        c.SetImage(values9)
+        c.SetImage(values9)  # type:ignore[arg-type]
 
 
-def testSlice(unit_database):
+def testSlice(unit_database) -> None:
     quantity = ObtainQuantity("m", "length")
 
     def MakeArray(values):
@@ -67,16 +70,16 @@ def testSlice(unit_database):
     assert curve[:] == ([5, 10, 20, 30, 40, 50], [0, 1, 2, 3, 4, 5])
 
 
-def testCurveRepr(unit_database):
+def testCurveRepr(unit_database) -> None:
     q1 = ObtainQuantity("m", "length")
     q2 = ObtainQuantity("d", "time")
-    curve = Curve(Array(q1, []), Array(q2, []))
+    curve = Curve(Array(q1, []), Array(q2, []))  # type:ignore[arg-type]
     assert "Curve(m, d)[]" == repr(curve)
 
-    curve = Curve(Array(q1, list(range(3))), Array(q2, list(range(3))))
+    curve = Curve(Array(q1, list(range(3))), Array(q2, list(range(3))))  # type:ignore[arg-type]
     assert "Curve(m, d)[(0, 0) (1, 1) (2, 2)]" == repr(curve)
 
-    curve = Curve(Array(q1, list(range(100))), Array(q2, list(range(100))))
+    curve = Curve(Array(q1, list(range(100))), Array(q2, list(range(100))))  # type:ignore[arg-type]
     expected = (
         "Curve(m, d)[(0, 0) (1, 1) (2, 2) (3, 3) (4, 4) (5, 5) "
         "(6, 6) (7, 7) (8, 8) (9, 9) (10, 10) (11, 11) "
