@@ -1,33 +1,35 @@
 """
 This module provides the implementation of an Quantity object.
 """
-from collections import OrderedDict
+
 from typing import Any
 from typing import ClassVar
 from typing import Dict
 from typing import List
 from typing import NoReturn
 from typing import Optional
-from typing import overload
 from typing import Sequence
 from typing import Tuple
 from typing import TypeVar
 from typing import Union
+from typing import overload
 
+from collections import OrderedDict
 from oop_ext.interface import ImplementsInterface
 
+from barril.units.exceptions import QuantityValidationError
+from barril.units.unit_database import CategoryInfo
+from barril.units.unit_database import FixUnitIfIsLegacy
+from barril.units.unit_database import InvalidUnitError
+from barril.units.unit_database import UnitDatabase
+from barril.units.unit_database import UnitsError
+
 from ._unit_constants import UNKNOWN_UNIT
 from .interfaces import IQuantity
 from .interfaces import IQuantity2
 from .interfaces import IQuantity3
 from .interfaces import IQuantity6
 from .interfaces import UnitExponentTuple
-from barril.units.exceptions import QuantityValidationError
-from barril.units.unit_database import CategoryInfo
-from barril.units.unit_database import FixUnitIfIsLegacy
-from barril.units.unit_database import InvalidUnitError
-from barril.units.unit_database import UnitDatabase
-from barril.units.unit_database import UnitsError
 
 __all__ = ["Quantity", "ObtainQuantity"]
 
@@ -37,16 +39,14 @@ def ObtainQuantity(
     unit: str,
     category: Optional[str] = None,
     unknown_unit_caption: Optional[str] = None,
-) -> "Quantity":
-    ...
+) -> "Quantity": ...
 
 
 @overload
 def ObtainQuantity(
     unit: str,
     category: Union[Tuple[str, ...], str],
-) -> "Quantity":
-    ...
+) -> "Quantity": ...
 
 
 @overload
@@ -54,8 +54,7 @@ def ObtainQuantity(
     unit: Union[None, List[UnitExponentTuple], Dict[str, Sequence[Union[str, int]]]],
     category: Optional[str] = None,
     unknown_unit_caption: Optional[str] = None,
-) -> "Quantity":
-    ...
+) -> "Quantity": ...
 
 
 def ObtainQuantity(
@@ -470,7 +469,7 @@ class Quantity:
                 self.GetCategory(), self._unit, self._unknown_unit_caption
             )
 
-        return "Quantity({!r}, {!r})".format(self.GetCategory(), self._unit)
+        return f"Quantity({self.GetCategory()!r}, {self._unit!r})"
 
     def SetUnknownCaption(self, caption: str) -> NoReturn:
         raise ReadOnlyError("Quantity is now read-only.")
@@ -527,7 +526,7 @@ class Quantity:
                         ret += "1 / "
 
                 if exp != -1:
-                    ret += "({}) ** {}".format(rep, abs(exp))
+                    ret += f"({rep}) ** {abs(exp)}"
                 else:
                     ret += rep
 
