@@ -432,6 +432,12 @@ def testDensityDerivativePerTemperatureUnitConversion() -> None:
     assert density_derivative_per_temperature.GetValue("kg/m3.degC") == 1.0
 
 
+def testDensityDerivativePerEnthalpyUnitConversion() -> None:
+    default = units.Scalar("density derivative in respect to enthalpy", 1, "kg2/m3.J")
+    assert default.value == 1.0
+    assert default.GetValue("kg2/m3.J") == 1.0
+
+
 def testStandardVolumePerStandardVolumeSmoke() -> None:
     standard_per_standard = units.Scalar(
         "standard volume per standard volume", 1, "scm(15C)/scm(15C)"
@@ -485,6 +491,24 @@ def testProductivityIndex() -> None:
     assert default.GetValue("m3/d/kgf/cm2") == approx(8472945600.38827)
 
 
+def testForchheimerLinearCoefficient() -> None:
+    default = units.Scalar("forchheimer linear productivity index", 1, "Pa2.s/scm")
+    assert default.value == 1.0
+    assert default.GetValue("Pa2.d/scm") == approx(1.1574074074074073e-05)
+    assert default.GetValue("psi2.d/scf") == approx(6.89434766020926e-15)
+    assert default.GetValue("psi2.d/Mscf") == approx(6.89434766020926e-12)
+    assert default.GetValue("bar2.d/scm") == approx(1.1574074074074073e-15)
+
+
+def testForchheimerQuadraticCoefficient() -> None:
+    default = units.Scalar("forchheimer quadratic productivity index", 1, "Pa2.s2/scm2")
+    assert default.value == 1.0
+    assert default.GetValue("Pa2.d2/scm2") == approx(1.3395919067215364e-10)
+    assert default.GetValue("psi2.d2/scf2") == approx(2.259562326921988e-21)
+    assert default.GetValue("psi2.d2/Mscf2") == approx(2.259562326921988e-19)
+    assert default.GetValue("bar2.d2/scm2") == approx(1.3395919067215364e-20)
+
+
 def testThermalConductivity() -> None:
     default = units.Scalar("thermal conductivity", 1, "W/m.K")
     assert default.GetValue("Btu/hr.ft.degF") == approx(0.5777892051642799)
@@ -519,3 +543,15 @@ def testStandardVolumePerTime() -> None:
     assert default.GetValue("sm3/d") == approx(86400.0)
     assert default.GetValue("stb/d") == approx(543439.6332285661)
     assert default.GetValue("sm3/s") == approx(1.0)
+
+
+def testHenrySolubilityCoefficient() -> None:
+    default = units.Scalar("henry solubility coefficient", 1.0, "mol/m3.Pa")
+    assert default.value == 1.0
+    assert default.GetValue("mol/m3.Pa") == 1.0
+
+
+def testCrystallizationKineticRate() -> None:
+    default = units.Scalar("crystallization kinetic rate", 1.0, "mol/m2.s.Pa")
+    assert default.value == 1.0
+    assert default.GetValue("mol/m2.s.Pa") == 1.0
