@@ -1,6 +1,8 @@
-from typing import Dict, Tuple
+from typing import Dict
+from typing import Tuple
 
-from barril.units.unit_database import InvalidUnitError, UnitDatabase
+from barril.units.unit_database import InvalidUnitError
+from barril.units.unit_database import UnitDatabase
 
 
 class _SimpleScalar:
@@ -68,7 +70,7 @@ class _ComposingQuantity:
         self._category_to_unit_and_exps = category_to_unit_and_exps
 
 
-def testScalarRefactor():
+def testScalarRefactor() -> None:
     quantity = _ObtainQuantity("m")
     quantity2 = _ObtainQuantity("m")
     assert "Quantity(length, m)" == str(quantity)
