@@ -1,3 +1,8 @@
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from barril.units import Quantity
+
 # constants for unknown quantities
 UNKNOWN_QUANTITY_TYPE = "Unknown"
 UNKNOWN_UNIT = "<unknown>"
@@ -5,9 +10,8 @@ UNKNOWN_UNIT = "<unknown>"
 LENGTH_QUANTITY_TYPE = "length"
 
 
-def CreateUnknwonwReadOnlyQuantity():
+def CreateUnknwonwReadOnlyQuantity() -> "Quantity":
     """
-    :rtype: Quantity
     :returns:
         Returns a read only quantity for an unknown quantity.
     """
