@@ -1,9 +1,6 @@
-import copy
-import math
-import traceback
+from typing import TYPE_CHECKING
 from typing import Any
 from typing import Callable
-from typing import cast
 from typing import Dict
 from typing import Hashable
 from typing import Iterator
@@ -13,17 +10,19 @@ from typing import Sequence
 from typing import Set
 from typing import Tuple
 from typing import Type
-from typing import TYPE_CHECKING
 from typing import TypeVar
 from typing import Union
+from typing import cast
 
 import attr
+import copy
+import math
+import traceback
 from oop_ext.foundation.singleton import Singleton
 
 from barril._util.types_ import CheckType
 from barril.units.interfaces import UnitExponentTuple
 
-
 if TYPE_CHECKING:
     from barril.units import Quantity
 
@@ -46,6 +45,8 @@ _LEGACY_TO_CURRENT: List[Tuple[str, str]] = [
     ("M(m3)", "MMm3"),
     ("k(ft3)", "Mcf"),
     ("Ns/m", "N.s/m"),
+    ("lbmole", "lbmol"),
+    ("gmole", "gmol"),
 ]
 
 
@@ -449,7 +450,7 @@ class UnitDatabase(Singleton):
         if min_value is not None and max_value is not None:
             if max_value < min_value:
                 raise ValueError(
-                    "min_value (%s) must be >= than min_value (%s)" % (min_value, max_value)
+                    "min_value ({}) must be >= than min_value ({})".format(min_value, max_value)
                 )
 
         if from_category:
@@ -478,8 +479,11 @@ class UnitDatabase(Singleton):
         if valid_units is not None:
             # valid units given: check if all the given units are valid
             quantity_units = set(self.GetUnits(quantity_type))
-            for unit in valid_units:
-                if unit not in quantity_units:
+            for i, unit in enumerate(valid_units):
+                was_unit_fixed, fixed_unit = FixUnitIfIsLegacy(unit)
+                if was_unit_fixed:
+                    valid_units[i] = fixed_unit
+                if fixed_unit not in quantity_units:
                     msg = "unit %r is not valid for quantity type %r.\nQuantity units: %r"
                     raise ValueError(msg % (unit, quantity_type, sorted(quantity_units)))
 
@@ -490,6 +494,9 @@ class UnitDatabase(Singleton):
                 default_unit = valid_units[0]
         else:
             quantity_units = set(self.GetUnits(quantity_type))
+            was_unit_fixed, fixed_default_unit = FixUnitIfIsLegacy(default_unit)
+            if was_unit_fixed:
+                default_unit = fixed_default_unit
             if default_unit not in quantity_units:
                 raise ValueError(
                     "unit %r is not valid for default quantity type %r"
@@ -786,7 +793,7 @@ class UnitDatabase(Singleton):
         quantity_type_list = self.quantity_types.setdefault(quantity_type, [])
 
         if unit in [q.unit for q in quantity_type_list]:
-            raise RuntimeError("Unit already registered: %s (%s)" % (name, unit))
+            raise RuntimeError("Unit already registered: {} ({})".format(name, unit))
 
         quantity_type_list.append(info)
 
@@ -981,7 +988,8 @@ class UnitDatabase(Singleton):
                     # says it's unknown, but we get a proper label for it in the UI, thus, it's a
                     # known 'unknown' quantity). So, in this case, proceed returning the unknown
                     # quantity unit information.
-                    from ._unit_constants import UNKNOWN_QUANTITY_TYPE, UNKNOWN_UNIT
+                    from ._unit_constants import UNKNOWN_QUANTITY_TYPE
+                    from ._unit_constants import UNKNOWN_UNIT
 
                     if quantity_type == UNKNOWN_QUANTITY_TYPE:
                         quantity_types = self.quantity_types[quantity_type]
@@ -1424,7 +1432,7 @@ class UnitDatabase(Singleton):
                     unit_exp1[1] = operation_exp(exp1, exp2)  # type:ignore[index]
                 else:
                     raise RuntimeError(
-                        "This should've been covered already (%s != %s)." % (unit1, unit2)
+                        "This should've been covered already ({} != {}).".format(unit1, unit2)
                     )
 
         # unit -> expoent
