@@ -291,8 +291,8 @@ class UnitRichTextRepresentations:
         "ft2/d": "ft<sup>2</sup>/d",
         "mol/m2.s": "mol/m<sup>2</sup>.s",
         "mol(lbm)/h.ft2": "mol(lbm)/h.ft<sup>2</sup>",
-        "lbmole/h.ft2": "lbmole/h.ft<sup>2</sup>",
-        "lbmole/s.ft2": "lbmole/s.ft<sup>2</sup>",
+        "lbmol/h.ft2": "lbmol/h.ft<sup>2</sup>",
+        "lbmol/s.ft2": "lbmol/s.ft<sup>2</sup>",
         "mol(lbm)/s.ft2": "mol(lbm)/s.ft<sup>2</sup>",
         "W/m2": "W/m<sup>2</sup>",
         "Btu/hr.ft2": "Btu/hr.ft<sup>2</sup>",
@@ -316,7 +316,7 @@ class UnitRichTextRepresentations:
         "mol/m3": "mol/m<sup>3</sup>",
         "kmol/m3": "kmol/m<sup>3</sup>",
         "mol(kg)/m3": "mol(kg)/m<sup>3</sup>",
-        "lbmole/ft3": "lbmole/ft<sup>3</sup>",
+        "lbmol/ft3": "lbmol/ft<sup>3</sup>",
         "mol(lbm)/ft3": "mol(lbm)/ft<sup>3</sup>",
         "m4/s": "m<sup>4</sup>/s",
         "1000m4/d": "1000m<sup>4</sup>/d",
@@ -399,7 +399,7 @@ class UnitRichTextRepresentations:
         "mol/m3": "mol/m<sup>3</sup>",
         "kmol/m3": "kmol/m<sup>3</sup>",
         "mol(kg)/m3": "mol(kg)/m<sup>3</sup>",
-        "lbmole/ft3": "lbmole/ft<sup>3</sup>",
+        "lbmol/ft3": "lbmol/ft<sup>3</sup>",
         "mol(lbm)/ft3": "mol(lbm)/ft<sup>3</sup>",
         "m3/J": "m<sup>3</sup>/J",
         "dm3/kW.h": "dm<sup>3</sup>/kW.h",
@@ -670,7 +670,7 @@ class UnitRichTextRepresentations:
         "m3/mol": "m<sup>3</sup>/mol",
         "dm3/kmol": "dm<sup>3</sup>/kmol",
         "dm3/mol(kg)": "dm<sup>3</sup>/mol(kg)",
-        "ft3/lbmole": "ft<sup>3</sup>/lbmole",
+        "ft3/lbmol": "ft<sup>3</sup>/lbmol",
         "ft3/mol(lbm)": "ft<sup>3</sup>/mol(lbm)",
         "m3/kmol": "m<sup>3</sup>/kmol",
         "m3/mol(kg)": "m<sup>3</sup>/mol(kg)",
